import type { FaultKnowVO } from './model';

import type { ID, IDS } from '#/api/common';

import { commonExport } from '#/api/helper';
import { requestClient } from '#/api/request';

enum Api {
  faultKnowExport = '/eims/faultKnow/export',
  faultKnowList = '/eims/faultKnow/list',
  root = '/eims/faultKnow'
}

/**
 * 查询故障知识列表
 * @param params
 * @returns {*}
 */

export function listFaultKnow(params?: any) {
  return requestClient.get<FaultKnowVO[]>(Api.faultKnowList, { params });
}

/**
 * 查询故障知识详细
 * @param faultKnowId
 */
export function getFaultKnow(faultKnowId: ID) {
  return requestClient.get<FaultKnowVO>(`${Api.root}/${faultKnowId}`);
}

/**
 * 新增故障知识
 * @param data
 */
export function addFaultKnow(data: any) {
  return requestClient.postWithMsg<void>(Api.root, data);
}

/**
 * 修改故障知识
 * @param data
 */
export function updateFaultKnow(data: any) {
  return requestClient.putWithMsg<void>(Api.root, data);
}

/**
 * 删除故障知识
 * @param faultKnowId
 */
export function delFaultKnow(faultKnowId: IDS) {
  return requestClient.deleteWithMsg<void>(`${Api.root}/${faultKnowId}`);
}
/**
 * 导出
 * @param
 */
export function faultKnowExport(data: any) {
  return commonExport(Api.faultKnowExport, data);
}
